Module benchmark

Module benchmark 

Contains a benchmark that simulates the performance of different types of students using a given set of courses and scheduler options. The goal is to evaluate the performance of the scheduler in terms of the time to mastery for different student profiles.

Structs

Benchmark
Runs several simulations of different student profiles to benchmark the performance of the scheduler given the provided library and options.
BenchmarkResult
The result of running the entire benchmark. See the definitions of the individual students in the Benchmark struct.
StudentProfile
Describes the information that is used to simulate the performance of different types of students.
StudentResult
The result of running a benchmark for a student profile.

Functions

verify_probs
Validates that the probabilities sum up to 1.0.

Type Aliases

PerformanceProbs
Probabilities for each mastery score (1 through 5) given by a student for an individual exercise. Indices 0..4 correspond to scores 1..5. Probabilities must sum up to 1.0.