StudentProfile

Struct StudentProfile 

pub struct StudentProfile {
    pub session_frequency: u32,
    pub exercises_per_session: u32,
    pub initial_performance: PerformanceProbs,
    pub trials_before_stable: u32,
    pub stable_performance: PerformanceProbs,
    pub lapse_rate: f32,
}
Describes the information that is used to simulate the performance of different types of students.

Fields

session_frequency: u32

The frequency at which the student practices expressed as how many days there are in between practice sessions. For example, a frequency of 2 means that the student practices every 2 days.

exercises_per_session: u32

The number of exercises that the student practices in each session.

initial_performance: PerformanceProbs

The initial performance of the student when they see an exercise for the first time.

trials_before_stable: u32

The number of trials the student needs to reach stable performance.

stable_performance: PerformanceProbs

The stable performance of the student after they have practiced an exercise a large number of trials. The probabilities of trials in between the initial and the stable trials are interpolated.

lapse_rate: f32

The rate at which the student lapses on an exercise after the stable performance is reached. Used to simulate forgetting, even after reaching stable performance.