pub struct Instrument {
pub name: String,
pub id: String,
}Expand description
Describes an instrument that can be used to practice in a generated course.
Fields
name: StringThe name of the instrument. For example, “Tenor Saxophone”.
id: StringAn ID for this instrument used to generate lesson IDs. For example, “tenor_saxophone”.