Enum trane::data::BasicAsset
source · pub enum BasicAsset {
MarkdownAsset {
path: String,
},
InlinedAsset {
content: String,
},
InlinedUniqueAsset {
content: Ustr,
},
}Expand description
An asset attached to a unit, which could be used to store instructions, or present the material introduced by a course or lesson.
Variants
MarkdownAsset
An asset containing the path to a markdown file.
InlinedAsset
An asset containing its content as a string.
InlinedUniqueAsset
An asset containing its content as a unique string. Useful for generating assets that are replicated across many units.