pub enum ExerciseType {
Declarative,
Procedural,
}Expand description
The type of knowledge tested by an exercise.
Variants
Declarative
Represents an exercise that tests mastery of factual knowledge. For example, an exercise asking students to name the notes in a D Major chord.
Procedural
Represents an exercises that requires more complex actions to be performed. For example, an exercise asking students to play a D Major chords in a piano.