MasteryScore

Enum MasteryScore 

pub enum MasteryScore {
    One,
    Two,
    Three,
    Four,
    Five,
}
The score used by students to evaluate their mastery of a particular exercise after a trial. More detailed descriptions of the levels are provided using the example of an exercise that requires the student to learn a musical passage.

Variants



One

One signifies the student has barely any mastery of the exercise. For a musical passage, this level of mastery represents the initial attempts at hearing and reading the music, and figuring out the movements required to perform it.



Two

Two signifies the student has achieved some mastery of the exercise. For a musical passage, this level of mastery represents the stage at which the student knows the music, the required movements, and can perform the passage slowly with some mistakes.



Three

Three signifies the student has achieved significant mastery of the exercise. For a musical passage, this level of mastery represents the stage at which the student can perform the material slowly with barely any mistakes, and has begun to learn it at higher tempos.



Four

Four signifies the student has gained mastery of the exercise, requiring almost not conscious thought to complete it. For a musical passage, this level of mastery represents the stage at which the student can perform the material at the desired tempo with all elements (rhythm, dynamics, etc.) completely integrated into the performance.



Five

Five signifies the student has gained total mastery of the material and can apply it in novel situations and come up with new variations. For exercises that test declarative knowledge or that do not easily lend themselves for variations (e.g., a question on some programming language’s feature), the difference between the fourth and fifth level is just a matter of increased speed and accuracy. For a musical passage, this level of mastery represents the stage at which the student can perform the material without making mistakes. In addition, they can also play their own variations of the material by modifying the melody, harmony, dynamics, rhythm, etc., and do so effortlessly.

Implementations

Source

impl MasteryScore

pub fn float_score(&self) -> f32

Assigns a float value to each of the values of MasteryScore.