pub enum ExerciseFilter {
UnitFilter(UnitFilter),
StudySession(StudySessionData),
}Expand description
A set of options to control which exercises should be considered to be included in the final batch.
Variants
UnitFilter(UnitFilter)
Select exercises based on a unit filter.
StudySession(StudySessionData)
Select exercises based on a study session.