UnitFilter

Enum UnitFilter 

pub enum UnitFilter {
    CourseFilter {
        course_ids: Vec<Ustr>,
    },
    LessonFilter {
        lesson_ids: Vec<Ustr>,
    },
    MetadataFilter {
        filter: KeyValueFilter,
    },
    ReviewListFilter,
    Dependents {
        unit_ids: Vec<Ustr>,
    },
    Dependencies {
        unit_ids: Vec<Ustr>,
        depth: usize,
    },
}
A filter on a course or lesson manifest.

Variants



CourseFilter

A filter to show exercises belonging to the given courses.

Fields

course_ids: Vec<Ustr>

The IDs of the courses to filter.



LessonFilter

A filter to show exercises belonging to the given lessons.

Fields

lesson_ids: Vec<Ustr>

The IDs of the lessons to filter.



MetadataFilter

A filter on the metadata of a course or lesson.

Fields

filter: KeyValueFilter

The filter to apply to the course or lesson metadata.



ReviewListFilter

A filter that indicates only exercises from the review list should be scheduled.



Dependents

A filter that schedules exercises from all the given units and its dependents.

Fields

unit_ids: Vec<Ustr>

The IDs of the units from which to start the search.



Dependencies

A filter that schedules exercises from the dependencies of the given units.

Fields

unit_ids: Vec<Ustr>

The IDs from which to look up the dependencies.

depth: usize

The depth of the dependency tree to search.

Implementations

Source

impl UnitFilter

pub fn passes_course_filter(&self, course_id: &Ustr) -> bool

Returns whether the course with the given ID passes the course filter.

pub fn passes_lesson_filter(&self, lesson_id: &Ustr) -> bool

Returns whether the lesson with the given ID passes the lesson filter.