pub struct StudySession {
pub id: String,
pub description: String,
pub parts: Vec<SessionPart>,
}Expand description
A study session is a list of parts, each of which define the exercises to study and for how long. For example, a student learning to play piano and guitar could define a session that spends 30 minutes on exercises for piano, and 30 minutes on exercises for guitar.
Fields
id: StringA unique identifier for the study session.
description: StringA human-readable description for the study session.
parts: Vec<SessionPart>The parts of the study session.