CourseManifest

Struct CourseManifest 

pub struct CourseManifest {
    pub id: Ustr,
    pub name: String,
    pub dependencies: Vec<Ustr>,
    pub encompassed: Vec<(Ustr, f32)>,
    pub superseded: Vec<Ustr>,
    pub description: Option<String>,
    pub authors: Option<Vec<String>>,
    pub metadata: Option<BTreeMap<String, Vec<String>>>,
    pub course_material: Option<BasicAsset>,
    pub course_instructions: Option<BasicAsset>,
    pub generator_config: Option<CourseGenerator>,
}
A manifest describing the contents of a course.

Fields

id: Ustr

The ID assigned to this course.

For example, music::instrument::guitar::basic_jazz_chords.

name: String

The name of the course to be presented to the user.

For example, “Basic Jazz Chords on Guitar”.

dependencies: Vec<Ustr>

The IDs of all dependencies of this course.

encompassed: Vec<(Ustr, f32)>

The IDs of the courses or lessons encompassed by this course expressed as a tuple (ID, weight). By default, all dependencies are encompassed with a weight of 1.0. Adding an entry to this list is only needed when:

  • A course or lesson that is not a dependency of this course is encompassed by it.
  • A dependency relationship does not always imply an encompassing one. In that case, such dependencies should be added to this list with a weight of 0.0.

See the documentation of the graph and scheduler modules for a full explanation of this concept and how it is used to reduce reviews of exercises that are covered by those in other units.

superseded: Vec<Ustr>

The IDs of the courses or lessons superseded by this course. If this course is mastered, then exercises from the superseded courses or lessons will no longer be shown to the student.

description: Option<String>

An optional description of the course.

authors: Option<Vec<String>>

An optional list of the course’s authors.

metadata: Option<BTreeMap<String, Vec<String>>>

be attached to a course named “Basic Jazz Chords on Guitar”.

The purpose of this metadata is to allow students to focus on more specific material during a study session which does not belong to a single lesson or course. For example, a student might want to only focus on guitar scales or ear training.

course_material: Option<BasicAsset>

An optional asset, which presents the material covered in the course.

course_instructions: Option<BasicAsset>

An optional asset, which presents instructions common to all exercises in the course.

generator_config: Option<CourseGenerator>

An optional configuration to generate material for this course. Generated courses allow easier creation of courses for specific purposes without requiring the manual creation of all the files a normal course would need.