pub struct ExerciseManifest {
pub id: Ustr,
pub lesson_id: Ustr,
pub course_id: Ustr,
pub name: String,
pub description: Option<String>,
pub exercise_type: ExerciseType,
pub exercise_asset: ExerciseAsset,
}Expand description
Manifest describing a single exercise.
Fields
id: UstrThe ID assigned to this exercise.
For example, music::instrument::guitar::basic_jazz_chords::major_chords::exercise_1.
lesson_id: UstrThe ID of the lesson to which this exercise belongs.
course_id: UstrThe ID of the course to which this exercise belongs.
name: StringThe name of the exercise to be presented to the user.
For example, “Exercise 1”.
description: Option<String>An optional description of the exercise.
exercise_type: ExerciseTypeThe type of knowledge the exercise tests.
exercise_asset: ExerciseAssetThe asset containing the exercise itself.