pub struct GeneratedCourse {
pub lessons: Vec<(LessonManifest, Vec<ExerciseManifest>)>,
pub updated_metadata: Option<BTreeMap<String, Vec<String>>>,
pub updated_instructions: Option<BasicAsset>,
}Expand description
A struct holding the results from running a course generator.
Fields
lessons: Vec<(LessonManifest, Vec<ExerciseManifest>)>The lessons and exercise manifests generated for the course.
updated_metadata: Option<BTreeMap<String, Vec<String>>>Updated course metadata. If None, the existing metadata is used.
updated_instructions: Option<BasicAsset>Updated course instructions. If None, the existing instructions are used.