pub trait GetMetadata {
// Required method
fn get_metadata(&self) -> Option<&BTreeMap<String, Vec<String>>>;
}Expand description
Trait to get the metadata from a lesson or course manifest.
pub trait GetMetadata {
// Required method
fn get_metadata(&self) -> Option<&BTreeMap<String, Vec<String>>>;
}Trait to get the metadata from a lesson or course manifest.