InMemoryUnitGraph

Struct InMemoryUnitGraph 

pub struct InMemoryUnitGraph { /* private fields */ }
An implementation of UnitGraph describing the units and relationships as an adjacency list stored in hash maps. All of it is stored in memory, as the memory benchmarks show that less than 20 MB of memory are used even when opening a large Trane library.