DepthFirstScheduler

Struct DepthFirstScheduler 

pub struct DepthFirstScheduler { /* private fields */ }
An implementation of ExerciseScheduler based on depth-first search.

Implementations

Source

impl DepthFirstScheduler

pub fn new(data: SchedulerData) -> Self

Creates a new scheduler.

pub fn get_course_valid_starting_lessons( &self, course_id: Ustr, metadata_filter: Option<&KeyValueFilter>, ) -> Result<Vec<Ustr>>

Returns the lessons in the course that have no dependencies with other lessons in the course and whose dependencies are satisfied.