Trane

Struct Trane 

pub struct Trane { /* private fields */ }
Trane is a library for the acquisition of highly hierarchical knowledge and skills based on the principles of mastery learning and spaced repetition. Given a list of courses, its lessons and corresponding exercises, Trane presents the student with a list of exercises based on the demonstrated mastery of previous exercises. It makes sure that new material and skills are not introduced until the prerequisite material and skills have been sufficiently mastered.

Implementations

Source

impl Trane

pub fn new_local(working_dir: &Path, library_root: &Path) -> Result<Trane>

Creates a new local instance of the Trane given the path to the root of a course library. The user data will be stored in a directory named .trane inside the library root directory. The working directory will be used to resolve relative paths.

pub fn new_local_from_serialized( library_root: &Path, serialized_library: SerializedCourseLibrary, ) -> Result<Trane>

Creates a new local instance of the Trane given the path to the root of a course library. The user data will be stored in a directory named .trane inside the library root directory. The working directory will be used to resolve relative paths.

pub fn library_root(&self) -> String

Returns the path to the root of the course library.