pub enum UnitFilter {
CourseFilter {
course_ids: Vec<Ustr>,
},
LessonFilter {
lesson_ids: Vec<Ustr>,
},
MetadataFilter {
filter: KeyValueFilter,
},
ReviewListFilter,
Dependents {
unit_ids: Vec<Ustr>,
},
Dependencies {
unit_ids: Vec<Ustr>,
depth: usize,
},
}Expand description
A filter on a course or lesson manifest.
Variants
CourseFilter
A filter to show exercises belonging to the given courses.
LessonFilter
A filter to show exercises belonging to the given lessons.
MetadataFilter
A filter on the metadata of a course or lesson.
Fields

filter: KeyValueFilterThe filter to apply to the course or lesson metadata.
ReviewListFilter
A filter that indicates only exercises from the review list should be scheduled.
Dependents
A filter that schedules exercises from all the given units and its dependents.
Dependencies
A filter that schedules exercises from the dependencies of the given units.
Implementations
Sourceimpl UnitFilter
impl UnitFilter
Sourcepub fn passes_course_filter(&self, course_id: &Ustr) -> bool
pub fn passes_course_filter(&self, course_id: &Ustr) -> bool
Returns whether the course with the given ID passes the course filter.
Sourcepub fn passes_lesson_filter(&self, lesson_id: &Ustr) -> bool
pub fn passes_lesson_filter(&self, lesson_id: &Ustr) -> bool
Returns whether the lesson with the given ID passes the lesson filter.