pub struct Note(pub NaturalNote, pub Accidental);Expand description
Defines the union of a natural note and an accidental that describes a note.
Tuple Fields
0: NaturalNote1: AccidentalImplementations
Sourceimpl Note
impl Note
Sourcepub fn all_keys(include_enharmonic: bool) -> Vec<Note>
pub fn all_keys(include_enharmonic: bool) -> Vec<Note>
Returns all the notes in the circle of fifths.
Sourcepub fn clockwise(&self) -> Option<Note>
pub fn clockwise(&self) -> Option<Note>
Returns the note obtained by moving clockwise through the circle of fifths.
Sourcepub fn counter_clockwise(&self) -> Option<Note>
pub fn counter_clockwise(&self) -> Option<Note>
Returns the note obtained by moving counter-clockwise through the circle of fifths.
Sourcepub fn previous_key_in_circle(&self) -> Option<Note>
pub fn previous_key_in_circle(&self) -> Option<Note>
Returns the previous key in the circle of fifths, that is, the key with one fewer sharp or flat.
Sourcepub fn last_keys_in_circle(include_enharmonic: bool) -> Vec<Note>
pub fn last_keys_in_circle(include_enharmonic: bool) -> Vec<Note>
Returns the last keys accessible by traversing the circle of fifths in clockwise and counter-clockwise directions.
Sourceimpl Note
impl Note
pub const A: Note
pub const A_FLAT: Note
pub const A_SHARP: Note
pub const B: Note
pub const B_FLAT: Note
pub const B_SHARP: Note
pub const C: Note
pub const C_FLAT: Note
pub const C_SHARP: Note
pub const D: Note
pub const D_FLAT: Note
pub const D_SHARP: Note
pub const E: Note
pub const E_FLAT: Note
pub const E_SHARP: Note
pub const F: Note
pub const F_FLAT: Note
pub const F_SHARP: Note
pub const G: Note
pub const G_FLAT: Note
pub const G_SHARP: Note
Sourcepub fn to_ascii_string(&self) -> String
pub fn to_ascii_string(&self) -> String
Returns a representation of the note without Unicode characters for use in directory names and other contexts where Unicode is harder or impossible to use.