pub struct MasteryWindow {
pub percentage: f32,
pub range: (f32, f32),
}Expand description
A mastery window consists a range of scores and the percentage of the total exercises in the batch returned by the scheduler that will fall within that range.
Mastery windows are used by the scheduler to control the amount of exercises for a given range of difficulty given to the student to try to keep an optimal balance. For example, exercises that are already fully mastered should not be shown very often lest the student becomes bored. Very difficult exercises should not be shown too often either lest the student becomes frustrated.
Fields
percentage: f32The percentage of the exercises in each batch returned by the scheduler whose scores should fall within this window.
range: (f32, f32)The range of scores which fall on this window. Scores whose values are in the range
[range.0, range.1) fall within this window. If range.1 is equal to 5.0 (the float
representation of the maximum possible score), then the range becomes inclusive.
Implementations