pub struct DepthFirstScheduler { /* private fields */ }Expand description
An implementation of ExerciseScheduler based on depth-first search.
Implementations
Sourceimpl DepthFirstScheduler
impl DepthFirstScheduler
Sourcepub fn new(data: SchedulerData) -> Self
pub fn new(data: SchedulerData) -> Self
Creates a new scheduler.
Sourcepub fn get_course_valid_starting_lessons(
&self,
course_id: Ustr,
metadata_filter: Option<&KeyValueFilter>,
) -> Result<Vec<Ustr>>
pub fn get_course_valid_starting_lessons( &self, course_id: Ustr, metadata_filter: Option<&KeyValueFilter>, ) -> Result<Vec<Ustr>>
Returns the lessons in the course that have no dependencies with other lessons in the course and whose dependencies are satisfied.