pub fn assert_simulation_scores(
exercise_id: Ustr,
trane: &Trane,
simulation_scores: &UstrMap<Vec<MasteryScore>>,
) -> Result<()>Expand description
Asserts that the scores in the simulation match the scores reported by Trane for the given exercise.